@@ -3,15 +3,13 @@ package Test::TCP;
 use strict;
 use warnings;
 use 5.00800;
-our $VERSION = '0.02';
-use Sub::Exporter -setup => {
-    exports => [
-        qw/ empty_port test_tcp wait_port /
-    ],
-    groups => { default => [':all'] }
-};
+our $VERSION = '0.04';
+use base qw/Exporter/;
 use IO::Socket::INET;
 use Params::Validate ':all';
+use Test::SharedFork;
+
+our @EXPORT = qw/ empty_port test_tcp wait_port /;
 
 sub empty_port {
     my $port = shift || 10000;
@@ -41,7 +39,7 @@ sub test_tcp {
 
     my $port = $args{port};
 
-    if ( my $pid = fork() ) {
+    if ( my $pid = Test::SharedFork->fork() ) {
         # parent.
         wait_port($port);
 
@@ -92,4 +90,4 @@ __END__
 
 =encoding utf8
 
-#line 161
+#line 173
