@@ -3,6 +3,7 @@ use strict;
 use warnings;
 use Scalar::Util        ();
 use Carp                ();
+use CGI::Simple::Cookie;
 
 sub finalize {
     my ($class, $req, $res) = @_;
@@ -45,7 +46,7 @@ sub finalize {
         $res->header( Connection => 'close' );
     }
 
-    $res->body('') if $req->method eq 'HEAD';
+    $res->body('') if ((defined $req->method) and ($req->method eq 'HEAD'));
 }
 
 sub _finalize_cookies  {
@@ -54,8 +55,6 @@ sub _finalize_cookies  {
     my $cookies = $res->cookies;
     my @keys = keys %$cookies;
     if (@keys) {
-        HTTP::Engine::Util::require_once('CGI/Simple/Cookie.pm');
-
         for my $name (@keys) {
             my $val = $cookies->{$name};
             my $cookie = (
